{% load i18n %}
<div class="card">
    <div class="card-body">
        <h5 class="card-title">{% translate MODSHIB_FORMS_TITLE %}</h5>
        <h6 class="card-subtitle mb-2 text-muted">{% translate "Déconnexion" %}</h6>
        <div class="card-text">
            {% translate "Vous êtes déconnecté." %}
        </div>
        <a href="/{{ APP_URL_BASE_PATH }}">{% translate "Retour à l'accueil" %}</a>
    </div>
</div>