{% extends "registration/reg_base.html" %}
{% load i18n %}
{% block head_title %}{% translate "Connexion SSO" %}{% endblock head_title %}
{% block content %}
    <div class="d-flex min-vh-100 justify-content-center align-items-center p-5">
        {% include "registration/_bloc_sso_fail.html" %}
    </div>
{% endblock content %}