{% load i18n %}
<div class="card">
    <div class="card-body">
        <h5 class="card-title">{% translate MODSHIB_FORMS_TITLE %}</h5>
        <h6 class="card-subtitle mb-2 text-muted">{% translate "Connexion SSO" %}</h6>
        <div class="card-text">
            {% translate "Le SSO ne peut pas être contacté." %}
        </div>
        <a href="{{ login_url }}">{% translate "Retour à la page d'authentification" %}</a>
    </div>
</div>